@@ -8,14 +8,14 @@ use Readonly;
 use Moose; use MooseX::StrictConstructor;
 use Types::Standard 'Str';
 
-our $VERSION = '0.05_4'; # TRIAL VERSION
+our $VERSION = '0.05_5'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
 has status => (
     is       => 'ro',
     isa      => Str,
-    required => 1);
+    required => 1,);
 
 __PACKAGE__->meta->make_immutable;
 1; # End of CloudFlare::Client::Exception::Connection
@@ -32,7 +32,7 @@ CloudFlare::Client::Exception::Connection - CloudFlare API Connection Exception
 
 =head1 VERSION
 
-version 0.05_4
+version 0.05_5
 
 =head1 SYNOPSIS
 
@@ -40,12 +40,12 @@ version 0.05_4
 
     CloudFlare::Client::Exception::Connection::->throw(
         message   => 'HTTPS connection failure',
-        status    => '404'
+        status    => '404',
     );
 
     my $e = CloudFlare::Client::Exception::Connection::->new(
         message   => 'HTTPS connection failure',
-        status    => '404'
+        status    => '404',
     );
     $e->throw;
 
@@ -67,7 +67,7 @@ On the class, throw a new exception
 
     CloudFlare::Client::Exception::Connection::->throw(
         message   => 'HTTPS connection failure',
-        status    => '404'
+        status    => '404',
     );
     ...
 
@@ -81,7 +81,7 @@ Construct a new exception
 
     my $e = CloudFlare::Client::Exception::Connection::->throw(
         message   => 'HTTPS connection failure',
-        errorcode => '404'
+        errorcode => '404',
     );
 
 =head1 SEE ALSO
