@@ -8,13 +8,13 @@ use Readonly;
 use Moose; use MooseX::StrictConstructor;
 use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = '0.05_4'; # TRIAL VERSION
+our $VERSION = '0.05_5'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
 has errorCode => (
     is       => 'ro',
-    isa      => ErrorCode);
+    isa      => ErrorCode,);
 
 __PACKAGE__->meta->make_immutable;
 1; # End of CloudFlare::Client::Exception::Upstream
@@ -31,7 +31,7 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version 0.05_4
+version 0.05_5
 
 =head1 SYNOPSIS
 
@@ -39,12 +39,12 @@ version 0.05_4
 
     CloudFlare::Client::Exception::Upstream::->throw(
         message   => 'Bad things occured',
-        errorCode => 'E_MAXAPI'
+        errorCode => 'E_MAXAPI',
     );
 
     my $e = CloudFlare::Client::Exception::Upstream::->new(
         message   => 'Bad things happened',
-        errorcode => 'E_MAXAPI'
+        errorcode => 'E_MAXAPI',
     );
     $e->throw;
 
@@ -52,12 +52,12 @@ version 0.05_4
 
 =head2 message
 
-The error message thrown upstream, readonly.
+The error message thrown upstream, readonly
 
 =head2 errorCode
 
 The error code thrown upstream, readonly. Valid values are undef,
-E_UNAUTH, E_INVLDINPUT or E_MAXAPI. Readonly.
+E_UNAUTH, E_INVLDINPUT or E_MAXAPI. Readonly
 
 =head1 METHODS
 
@@ -67,7 +67,7 @@ On the class, throw a new exception
 
     CloudFlare::Client::Exception::Upstream::->throw(
         message   => 'Bad things occured',
-        errorCode => 'E_MAXAPI'
+        errorCode => 'E_MAXAPI',
     );
     ...
 
@@ -81,7 +81,7 @@ Construct a new exception
 
     my $e = CloudFlare::Client::Exception::Upstream::->new(
         message   => 'Bad things happened',
-        errorcode => 'E_MAXAPI'
+        errorcode => 'E_MAXAPI',
     );
 
 =head1 SEE ALSO
